library(zoo)
library(reshape2)
library(dplyr)
library(ggplot2)
library(mgcv)
library(dlnm)
library(splines)
library(grid)
library(gridExtra)
library(lattice)
library(latticeExtra)
library(multipanelfigure)


# Environmental-biologic dataset:

## Richness:
sub.26w.6112 <- read.csv('Dataset and R code/dataset for richness analysis.csv', header=TRUE)

## Abundance:
sub.6w.6112 <- read.csv('Dataset and R code/dataset for abundance analysis.csv', header=TRUE)

##### Flow measure diagnostics ######

pairs(hydro.indices[hydro.indices$site!=812,],lower.panel = panel.smooth, upper.panel = panel.cor)
c<-varclus(as.matrix(hydro.indices[hydro.indices$site!=812,]),similarity = "pearson")
plot(c)

xyplot(q90norm ~ date,groups=site,data=sub.6w.6112,type="b",pch=19, par.settings = simpleTheme(col=c("black","grey","blue","green","red","cyan"), lwd=1), auto.key=list(space="top", columns=5, title="Site", cex.title=1, lines=TRUE, points=FALSE), xlab="Time")
xyplot(normq90 ~ date,groups=site,data=sub.6w.6112,type="b",pch=19, par.settings = simpleTheme(col=c("black","grey","blue","green","red","cyan"), lwd=1), auto.key=list(space="top", columns=5, title="Site", cex.title=1, lines=TRUE, points=FALSE), xlab="Time")
xyplot(maxnorm ~ date,groups=site,data=sub.6w.6112,type="b",pch=19, par.settings = simpleTheme(col=c("black","grey","blue","green","red","cyan"), lwd=1), auto.key=list(space="top", columns=5, title="Site", cex.title=1, lines=TRUE, points=FALSE), xlab="Time")
xyplot(normmax ~ date,groups=site,data=sub.6w.6112,type="b",pch=19, par.settings = simpleTheme(col=c("black","grey","blue","green","red","cyan"), lwd=1), auto.key=list(space="top", columns=5, title="Site", cex.title=1, lines=TRUE, points=FALSE), xlab="Time")
xyplot(meannorm ~ date,groups=site,data=sub.6w.6112,type="b",pch=19, par.settings = simpleTheme(col=c("black","grey","blue","green","red","cyan"), lwd=1), auto.key=list(space="top", columns=5, title="Site", cex.title=1, lines=TRUE, points=FALSE), xlab="Time")
xyplot(normmean ~ date,groups=site,data=sub.6w.6112,type="b",pch=19, par.settings = simpleTheme(col=c("black","grey","blue","green","red","cyan"), lwd=1), auto.key=list(space="top", columns=5, title="Site", cex.title=1, lines=TRUE, points=FALSE), xlab="Time")
xyplot(q80norm ~ date,groups=site,data=sub.6w.6112,type="b",pch=19, par.settings = simpleTheme(col=c("black","grey","blue","green","red","cyan"), lwd=1), auto.key=list(space="top", columns=5, title="Site", cex.title=1, lines=TRUE, points=FALSE), xlab="Time")
xyplot(normq80 ~ date,groups=site,data=sub.6w.6112,type="b",pch=19, par.settings = simpleTheme(col=c("black","grey","blue","green","red","cyan"), lwd=1), auto.key=list(space="top", columns=5, title="Site", cex.title=1, lines=TRUE, points=FALSE), xlab="Time")
xyplot(sub.6w.6112$'max/med' ~ date,groups=site,data=sub.6w.6112,type="b",pch=19, par.settings = simpleTheme(col=c("black","grey","blue","green","red","cyan"), lwd=1), auto.key=list(space="top", columns=5, title="Site", cex.title=1, lines=TRUE, points=FALSE), xlab="Time", ylab='max/med')
xyplot(sub.6w.6112$'q90/med' ~ date,groups=site,data=sub.6w.6112,type="b",pch=19, par.settings = simpleTheme(col=c("black","grey","blue","green","red","cyan"), lwd=1), auto.key=list(space="top", columns=5, title="Site", cex.title=1, lines=TRUE, points=FALSE), xlab="Time", ylab='q90/med')
xyplot(sub.6w.6112$'q80/med' ~ date,groups=site,data=sub.6w.6112,type="b",pch=19, par.settings = simpleTheme(col=c("black","grey","blue","green","red","cyan"), lwd=1), auto.key=list(space="top", columns=5, title="Site", cex.title=1, lines=TRUE, points=FALSE), xlab="Time", ylab='q80/med')
xyplot(sub.6w.6112$'meani/med' ~ date,groups=site,data=sub.6w.6112,type="b",pch=19, par.settings = simpleTheme(col=c("black","grey","blue","green","red","cyan"), lwd=1), auto.key=list(space="top", columns=5, title="Site", cex.title=1, lines=TRUE, points=FALSE), xlab="Time", ylab='meani/med')
xyplot(sub.6w.6112$'max/mean' ~ date,groups=site,data=sub.6w.6112,type="b",pch=19, par.settings = simpleTheme(col=c("black","grey","blue","green","red","cyan"), lwd=1), auto.key=list(space="top", columns=5, title="Site", cex.title=1, lines=TRUE, points=FALSE), xlab="Time", ylab='max/mean')
xyplot(sub.6w.6112$'q90/mean' ~ date,groups=site,data=sub.6w.6112,type="b",pch=19, par.settings = simpleTheme(col=c("black","grey","blue","green","red","cyan"), lwd=1), auto.key=list(space="top", columns=5, title="Site", cex.title=1, lines=TRUE, points=FALSE), xlab="Time", ylab='q90/mean')
xyplot(sub.6w.6112$'q80/mean' ~ date,groups=site,data=sub.6w.6112,type="b",pch=19, par.settings = simpleTheme(col=c("black","grey","blue","green","red","cyan"), lwd=1), auto.key=list(space="top", columns=5, title="Site", cex.title=1, lines=TRUE, points=FALSE), xlab="Time", ylab='q80/mean')
xyplot(sub.6w.6112$'meani/mean' ~ date,groups=site,data=sub.6w.6112,type="b",pch=19, par.settings = simpleTheme(col=c("black","grey","blue","green","red","cyan"), lwd=1), auto.key=list(space="top", columns=5, title="Site", cex.title=1, lines=TRUE, points=FALSE), xlab="Time", ylab='meani/mean')
xyplot(sub.6w.6112[sub.6w.6112$site==801,]$'max/med' ~ date,data=sub.6w.6112[sub.6w.6112$site==801,],type="b",pch=19, cex.title=1, lines=TRUE, points=FALSE, xlab="Time", ylab='q90/med')

################################################
### Univariate model testing ###

# Richness:
sub.26w.6112
flow.measures <- subset(sub.26w.6112, select=c('site', 'max/med','q90/med','q80/med','max/mean','meani/med','q90/mean','q80/mean','meani/mean'))

degree.knots <- c(1:3)

cb <- array(list(),c(8,3)) # number of flow indices and number of knots
rownames(cb) <- colnames(flow.measures[,-1])
colnames(cb) <- degree.knots

for (i in 1:dim(flow.measures[,-1])[2]){
  for (j in 1:3){
    cb[[i,j]] <- dlnm::crossbasis(flow.measures[,i+1], lag=65, argvar=list(fun="ns",knots=3), arglag=list(fun="ns", knots=degree.knots[j]),group=flow.measures$site)
  }}

model.lagflow <- array(lapply(cb, function(x){mgcv::gam(obs.richness ~ x + s(ec,k=6) + s(pH,k=6) + s(wtemp,k=6) + s(turb,k=6)+ s(vel,k=6), data=sub.26w.6112, family=tw(link="log"), na.action=na.exclude)}), c(10,3))

AIC <- matrix(sapply(model.lagflow, FUN=AIC), nrow=10, ncol=3)
BIC <- matrix(sapply(model.lagflow, FUN=BIC), nrow=10, ncol=3)

pvalue <- matrix(sapply(model.lagflow, function(x){summary(x)$pTerms.pv}), nrow=8, ncol=3)
exp.dev <-  matrix(sapply(model.lagflow, function(x){summary(x)$dev.expl}), nrow=8, ncol=3)

AIC.ns3.ns <- data.frame(round(AIC))
colnames(AIC.ns3.ns) <- c(1:3)
AIC.ns3.ns$id <- colnames(flow.measures[,-1])
AIC.ns3.ns$relationship <-rep('ns3-ns',8)

BIC.ns3.ns <- data.frame(round(BIC))
colnames(BIC.ns3.ns) <- c(1,2,3)
BIC.ns3.ns$id <- colnames(flow.measures[,-1])
BIC.ns3.ns$relationship <-rep('ns3-ns',8)

pvalue.ns3.ns <- data.frame(pvalue)
colnames(pvalue.ns3.ns) <- c(1,2,3)
pvalue.ns3.ns$id <- colnames(flow.measures[,-1])
pvalue.ns3.ns$relationship <-rep('ns3-ns',8)

exp.dev.ns3.ns <- data.frame(exp.dev)
colnames(exp.dev.ns3.ns) <- c(1,2,3)
exp.dev.ns3.ns$id <- colnames(flow.measures[,-1])
exp.dev.ns3.ns$relationship <-rep('ns3-ns',8)

##############################


degree.knots <- c(2:3)

cb <- array(list(),c(8,2)) # number of flow indices and number of knots
rownames(cb) <- colnames(flow.measures[,-1])
colnames(cb) <- degree.knots

for (i in 1:dim(flow.measures[,-1])[2]){
  for (j in 1:2){
    cb[[i,j]] <- dlnm::crossbasis(flow.measures[,i+1], lag=65, argvar=list(fun="ns",knots=3), arglag=list(fun="poly", degree=degree.knots[j]),group=flow.measures$site)
  }}

model.lagflow <- array(lapply(cb, function(x){mgcv::gam(obs.richness ~ x + s(ec,k=6) + s(pH,k=6) + s(wtemp,k=6) + s(turb,k=6)+ s(vel,k=6), data=sub.26w.6112, family=tw(link="log"), na.action=na.exclude)}), c(10,2))

AIC <- matrix(sapply(model.lagflow, FUN=AIC), nrow=8, ncol=2)
BIC <- matrix(sapply(model.lagflow, FUN=BIC), nrow=8, ncol=2)

pvalue <- matrix(sapply(model.lagflow, function(x){summary(x)$pTerms.pv}), nrow=8, ncol=2)
exp.dev <-  matrix(sapply(model.lagflow, function(x){summary(x)$dev.expl}), nrow=8, ncol=2)

AIC.ns3.poly <- data.frame(round(AIC))
colnames(AIC.ns3.poly) <- c(2,3)
AIC.ns3.poly$id <- colnames(flow.measures[,-1])
AIC.ns3.poly$relationship <-rep('ns3-poly',8)

BIC.ns3.poly <- data.frame(round(BIC))
colnames(BIC.ns3.poly) <- c(2,3)
BIC.ns3.poly$id <- colnames(flow.measures[,-1])
BIC.ns3.poly$relationship <-rep('ns3-poly',8)

pvalue.ns3.poly <- data.frame(pvalue)
colnames(pvalue.ns3.poly) <- c(2,3)
pvalue.ns3.poly$id <- colnames(flow.measures[,-1])
pvalue.ns3.poly$relationship <-rep('ns3-poly',8)

exp.dev.ns3.poly <- data.frame(exp.dev)
colnames(exp.dev.ns3.poly) <- c(2,3)
exp.dev.ns3.poly$id <- colnames(flow.measures[,-1])
exp.dev.ns3.poly$relationship <-rep('ns3-poly',8)

###################
cb <- array(list(),c(8,1)) # length of flow.measures and number of knots
rownames(cb) <- colnames(flow.measures[,-1])


for (i in 1:dim(flow.measures[,-1])[2]){
  cb[[i,1]] <- dlnm::crossbasis(flow.measures[,i+1], lag=65, argvar=list(fun="lin"), arglag=list(fun='lin'),group=flow.measures$site)
}

model.lagflow <- array(lapply(cb, function(x){mgcv::gam(obs.richness~ x + s(ec,k=6) + s(pH,k=6) + s(wtemp,k=6) + s(turb,k=6)+ s(vel,k=6), data=sub.26w.6112, family=tw(link="log"), na.action=na.exclude)}), c(10,1))

AIC <- matrix(sapply(model.lagflow, FUN=AIC), nrow=8, ncol=1)
BIC <- matrix(sapply(model.lagflow, FUN=BIC), nrow=8, ncol=1)

pvalue <- matrix(sapply(model.lagflow, function(x){summary(x)$pTerms.pv}), nrow=8, ncol=1)
exp.dev <-  matrix(sapply(model.lagflow, function(x){summary(x)$dev.expl}), nrow=8, ncol=1)

AIC.ns3.poly$'1' <- round(AIC)
BIC.ns3.poly$'1' <- round(BIC)
pvalue.ns3.poly$'1' <- pvalue
exp.dev.ns3.poly$'1' <- exp.dev

# AIC
AIC.check <- rbind.data.frame(AIC.lin.ns, AIC.lin2.ns, AIC.lin3.ns, AIC.ns1.ns, AIC.ns2.ns, AIC.ns3.ns, AIC.lin.poly[,c('1','2','3','id','relationship')], AIC.lin2.poly[,c('1','2','3','id','relationship')], AIC.lin3.poly[,c('1','2','3','id','relationship')],
                              AIC.ns1.poly[,c('1','2','3','id','relationship')], AIC.ns2.poly[,c('1','2','3','id','relationship')], AIC.ns3.poly[,c('1','2','3','id','relationship')])
knot.no <- c('1','2','3')
AIC.check.melt <- melt(AIC.check, id=c("id","relationship"), measure.vars=c(knot.no))
colnames(AIC.check.melt)[c(3,4)] <- c('lag.knots','AIC')

# BIC
BIC.check <- rbind.data.frame(BIC.lin.ns, BIC.lin2.ns, BIC.lin3.ns, BIC.ns1.ns, BIC.ns2.ns, BIC.ns3.ns, BIC.lin.poly[,c('1','2','3','id','relationship')], BIC.lin2.poly[,c('1','2','3','id','relationship')], BIC.lin3.poly[,c('1','2','3','id','relationship')],
                              BIC.ns1.poly[,c('1','2','3','id','relationship')], BIC.ns2.poly[,c('1','2','3','id','relationship')], BIC.ns3.poly[,c('1','2','3','id','relationship')])
BIC.check.melt <- melt(BIC.check, id=c("id","relationship"), measure.vars=c(knot.no))
colnames(BIC.check.melt)[c(3,4)] <- c('lag.knots','BIC')

# PVALUE
pvalue.check <- rbind.data.frame(pvalue.lin.ns, pvalue.lin2.ns, pvalue.lin3.ns, pvalue.ns1.ns, pvalue.ns2.ns, pvalue.ns3.ns, pvalue.lin.poly[,c('1','2','3','id','relationship')], pvalue.lin2.poly[,c('1','2','3','id','relationship')], pvalue.lin3.poly[,c('1','2','3','id','relationship')],
                                 pvalue.ns1.poly[,c('1','2','3','id','relationship')], pvalue.ns2.poly[,c('1','2','3','id','relationship')], pvalue.ns3.poly[,c('1','2','3','id','relationship')])

pvalue.check.melt <- melt(pvalue.check, id=c("id","relationship"), measure.vars=c(knot.no))
colnames(pvalue.check.melt)[c(3,4)] <- c('lag.knots','pvalue')

# EXP. DEV

exp.dev.check <- rbind.data.frame(exp.dev.lin.ns, exp.dev.lin2.ns, exp.dev.lin3.ns, exp.dev.ns1.ns, exp.dev.ns2.ns, exp.dev.ns3.ns, exp.dev.lin.poly[,c('1','2','3','id','relationship')], exp.dev.lin2.poly[,c('1','2','3','id','relationship')], exp.dev.lin3.poly[,c('1','2','3','id','relationship')],
                                  exp.dev.ns1.poly[,c('1','2','3','id','relationship')], exp.dev.ns2.poly[,c('1','2','3','id','relationship')], exp.dev.ns3.poly[,c('1','2','3','id','relationship')])

exp.dev.check.melt <- melt(exp.dev.check, id=c("id","relationship"), measure.vars=c(knot.no))
colnames(exp.dev.check.melt)[c(3,4)] <- c('lag.knots','exp.dev')

AIC.check.melt$BIC <- BIC.check.melt$BIC
AIC.check.melt$pvalue <-pvalue.check.melt$pvalue
AIC.check.melt$exp.dev <- exp.dev.check.melt$exp.dev
AICbased.rich <- AIC.check.melt[order(AIC.check.melt$AIC),]


nrow(AICbased[AICbased$AIC<1070,]) # 40
nrow(AICbased.rich[AICbased.rich$AIC<1085&AICbased.rich$BIC<1150,])

####### Fit richness model ######

#cb <- dlnm::crossbasis(flow.measures$`q90/med`, lag=65, argvar=list(fun='poly', degree=2), arglag=list(fun="ns", knots=1),group=flow.measures$site) # good, flow>23.
#cb <- dlnm::crossbasis(flow.measures$`q90/med`, lag=65, argvar=list(fun='ns', knots=1), arglag=list(fun="ns", knots=1),group=flow.measures$site) # good, flow>23.
#cb <- dlnm::crossbasis(flow.measures$`q90/med`, lag=65, argvar=list(fun='ns', knots=2), arglag=list(fun="ns", knots=2),group=flow.measures$site) # good, flow>23.
#cb <- dlnm::crossbasis(flow.measures$`q90/med`, lag=65, argvar=list(fun='poly', degree=2), arglag=list(fun="ns", knots=2),group=flow.measures$site) # good, flow>23.
#cb <- dlnm::crossbasis(flow.measures$`q90/med`, lag=65, argvar=list(fun='ns', knots=1), arglag=list(fun="ns", knots=2),group=flow.measures$site) # good, flow>23.
#cb <- dlnm::crossbasis(flow.measures$`q80/med`, lag=65, argvar=list(fun='lin'), arglag=list(fun='poly', degree=3),group=flow.measures$site) # good, flow>23.
#cb <- dlnm::crossbasis(flow.measures$`q90/med`, lag=65, argvar=list(fun='lin'), arglag=list(fun='ns', knots=3),group=flow.measures$site) # good, flow>23.
#cb <- dlnm::crossbasis(flow.measures$`max/med`, lag=65, argvar=list(fun='ns',knots=1), arglag=list(fun="poly", degree=2),group=flow.measures$site) # good, flow > 25
#cb <- dlnm::crossbasis(flow.measures$`max/med`, lag=65, argvar=list(fun='ns',knots=2), arglag=list(fun="poly", degree=2),group=flow.measures$site) # good, flow > 25
#cb <- dlnm::crossbasis(flow.measures$`max/med`, lag=65, argvar=list(fun='poly', degree=2), arglag=list(fun="poly", degree=3),group=flow.measures$site) # good, flow > 25

#cb <- dlnm::crossbasis(flow.measures$`max/med`, lag=65, argvar=list(fun='ns', knots=2), arglag=list(fun="poly", degree=3),group=flow.measures$site) # good, flow>23.
#cb <- dlnm::crossbasis(flow.measures$`max/med`, lag=65, argvar=list(fun='ns', knots=1), arglag=list(fun="ns", knots=1),group=flow.measures$site) # sig. interaction dist*n
#cb <- dlnm::crossbasis(flow.measures$`q90/med`, lag=65, argvar=list(fun='lin'), arglag=list(fun="ns", knots=2),group=flow.measures$site) # sig. ti(dist,n)
#cb <- dlnm::crossbasis(flow.measures$`max/med`, lag=65, argvar=list(fun='ns',knots=1), arglag=list(fun="ns", knots=2),group=flow.measures$site) # sig. ti(dist,n) 
#cb <- dlnm::crossbasis(flow.measures$`max/med`, lag=65, argvar=list(fun='ns',knots=1), arglag=list(fun="poly", degree=2),group=flow.measures$site) # good, flow > 25
#cb <- dlnm::crossbasis(flow.measures$`max/med`, lag=65, argvar=list(fun='ns',knots=1), arglag=list(fun="ns", knots=3),group=flow.measures$site) # sig. tn(dist,n)
#cb <- dlnm::crossbasis(flow.measures$`q90/med`, lag=65, argvar=list(fun='lin'), arglag=list(fun="poly", degree=2),group=flow.measures$site) # sig. tn(dist,n)
#cb <- dlnm::crossbasis(flow.measures$`q90/mean`, lag=65, argvar=list(fun='lin'), arglag=list(fun="poly", degree=2),group=flow.measures$site) # sig. tn(dist,n)
#cb <- dlnm::crossbasis(flow.measures$`max/med`, lag=65, argvar=list(fun='lin'), arglag=list(fun="ns", knots=2),group=flow.measures$site) # sig. tn(dist,n)
#cb <- dlnm::crossbasis(flow.measures$`q90/med`, lag=65, argvar=list(fun='poly',degree=3), arglag=list(fun="ns", knots=3),group=flow.measures$site) # sig. tn(dist,n)
#cb <- dlnm::crossbasis(flow.measures$`meani/mean`, lag=65, argvar=list(fun='lin'), arglag=list(fun="ns", knots=2),group=flow.measures$site) # sig. tn(dist,n)
#cb <- dlnm::crossbasis(flow.measures$`max/med`, lag=65, argvar=list(fun='poly',degree=2), arglag=list(fun="poly", degree=3),group=flow.measures$site) #
#cb <- dlnm::crossbasis(flow.measures$`max/med`, lag=65, argvar=list(fun='ns',knots=1), arglag=list(fun="poly", degree=2),group=flow.measures$site) # sig. tn(dist,n)

cb <- dlnm::crossbasis(flow.measures$`q90/med`, lag=65, argvar=list(fun='ns', knots=1), arglag=list(fun="ns", knots=1),group=flow.measures$site) # good, flow>23.
#median(flow.measures$`max/med`,na.rm=T)#3
#median(flow.measures$`q90/med`,na.rm=T)#2

model.lagflow <- mgcv::gam(obs.richness ~ cb + s(ec,k=6) + s(pH,k=6) + s(wtemp,k=6)+s(turb,k=6) + s(vel,k=6), data=sub.26w.6112, family=tw(link="log"), na.action=na.exclude)
summary(model.lagflow)$residual.df # 134.5
anova(model.lagflow)
concurvity(model.lagflow, full=F)
gam.check(model.lagflow)
plot(model.lagflow,pages=1)
xyplot(residuals(model.lagflow,type="response") ~ n,groups=dist,data=sub.26w.6112,type="b",pch=19,col=c("black","grey","blue","green","red","cyan"))
xyplot(residuals(model.lagflow,type="response") ~ n|dist,data=sub.26w.6112,type="b",pch=19)
summary(gam(residuals(model.lagflow,type="response") ~ ti(dist) + ti(n) +ti(dist,n), data=sub.26w.6112))
summary(gam(residuals(model.lagflow,type="response") ~ s(n), data=sub.26w.6112))
AIC(model.lagflow) #
BIC(model.lagflow)#

cp <- crosspred(cb, model.lagflow, cen=1,lag=c(0,65), by=0.1, cumul=TRUE)
#cp <- crosspred(cb, model.lagflow, cen=3, at=seq(min(sub.26w.6112$'q90/med'), max(sub.26w.6112$'q90/med'),length=30))

#cp <- crosspred(cb, model.lagflow, cen=1, from=0, to=30, lag=c(0,65), by=0.1, cumul=TRUE)
plot(cp,"3d", zlab="Relative effect", col="green", xlab="q90/med", main="Overall effect of flow on taxa richness \n Reference at q90/med=2",main.cex=0.7, expand=0.6,lwd=0.5)
plot(cp, "contour", key.title=title("RE"), xlab="q90/med", ylab="Lag")

# create EPS file for publication:

#setEPS()
#postscript("Delayed effect of flow on richness.eps", width=15, height=6, family='ArialMT')

tiff(filename='delayed effect on richness.tiff', width=130, height=100, units = 'mm', res=800,compression="lzw")
plot(cp, "contour", key.title=title("RE"), xlab="Hydrologic index (q90/med)", ylab="Lag (x 0.5 year)", main='Relative effect (RE) of flow on \n aquatic macroinvertebrate taxa richness, \n referenced against a q90/med of 2 (RE = 1)',cex.lab=0.9, cex.main=0.9)
dev.off()

tiff(filename='delayed effect on richness revised.tiff', width=130, height=90, units = 'mm', res=800,compression="lzw")
plot(cp, "contour", key.title=title("RE"), xlab="Hydrologic index (q90/med)", ylab="Lag (x 0.5 year)", main='Taxa richness',cex.lab=1, cex.main=1)
dev.off()

tiff(filename='delayed effect on abundance revised.tiff', width=130, height=90, units = 'mm', res=800,compression="lzw")
plot(cp2, "contour", key.title=title("RE"), xlab="Hydrologic index (q90/med)", ylab="", main="Total abundance", cex.lab=1, cex.main=1)
dev.off()

tiff(filename='richness.tiff', width=140, height=100, units = 'mm', res=800,compression="lzw")
plot(cp, "contour", key.title=title("RE"), xlab="Hydrologic index (q90/med)", ylab="Lag (x 0.5 year)", main='',cex.lab=0.9, cex.main=0.9)
dev.off()

#tiff(filename='delayed effect on richness.tiff', width=130, height=100, units = 'mm', res=800,compression="lzw")
#plot(cp,"3d", zlab="Relative effect", col="green", xlab="q90/med", main="Overall effect of flow on taxa richness \n Reference at q90/med=2", expand=0.6,lwd=0.5)
#dev.off()

#pdf(file = "delayed_flow_effect_on_richness.pdf")
#dev.new(width=20, height=20)
#par(family='sans') # default (Arial), 'mono'= Courier New, 'serif'= Times New Roman
#plot(cp, "contour", key.title=title("RE"), xlab="Hydrologic index (q90/med)", ylab="Lag (x 0.5 year)", main='Relative effect (RE) (centred on 1) of flow \n on aquatic macroinvertebrate richness')
#dev.off()

cp <- crosspred(cb, model.lagflow, from=1, cen=2,lag=c(0,65), by=0.1, cumul=TRUE)

tiff(filename='delayed effect on richness 2 check.tiff', width=260, height=100, units = 'mm', res=800,compression="lzw")
tiff(filename='delayed effect on richness 3 check.tiff', width=190, height=100, units = 'mm', res=800,compression="lzw")

par(mfrow=c(2,4),cex=0.65,cex.axis=0.8,las=1,tcl=-0.5)
plot(cp2, "slices", var=1.8, col=1, lwd=2,xlab="Lag", ylab="Relative effect")
title(main="(a) q90/med = 3", adj=0,line=1, font.main=1, cex.main=1)

plot(cp, "slices", var=10, col=1, lwd=2,xlab="Lag", ylab="Relative effect")
title(main="(b) q90/med = 10", adj=0,line=1, font.main=1, cex.main=1)

plot(cp, "slices", var=23, col=1, lwd=2,xlab="Lag", ylab="Relative effect")
title(main="(c) q90/med = 23", adj=0,line=1, font.main=1, cex.main=1)

plot(cp, "slices", var=32, col=1, lwd=2,xlab="Lag", ylab="Relative effect")
title(main="(d) q90/med = 32", adj=0,line=1, font.main=1, cex.main=1)


plot(cp, "slices", lag=0, col=1, lwd=2, xlab="q90/med", ylab="Relative effect")
title(main="(e) Lag = 0", adj=0,line=1, font.main=1, cex.main=1)

plot(cp, "slices", lag=20, col=1, lwd=2, xlab="q90/med", ylab="Relative effect")
title(main="(f) Lag = 20", adj=0,line=1, font.main=1, cex.main=1)

plot(cp, "slices", lag=40, col=1, lwd=2, xlab="q90/med", ylab="Relative effect")
title(main="(g) Lag = 40", adj=0,line=1, font.main=1, cex.main=1)

plot(cp, "slices", lag=65, col=1, lwd=2, xlab="q90/med", ylab="Relative effect")
title(main="(h) Lag = 65", adj=0,line=1, font.main=1, cex.main=1)

dev.off()


plot(cp, "overall", ylim=c(0,3),col=4, lwd=2, xlab="Flow index", ylab="Relative effect")

percentiles <- round(quantile(sub.6w.6112$'q90/med', c(0.5, 0.90, 0.95, 0.99,0.999)))
cp <- crosspred(cb, model.lagflow, at=c(1,percentiles), cen=3, lag=c(0,65), by=0.2, cumul=TRUE)
plot(cp, "slices", var=1, col=1, ylim=c(0.5,1.4), lwd=2, ylab="Relative effect", main="Lag response curves of richness at different levels of flows, \n reference. at 3")
for(i in 1:4) lines(cp, "slices", var=percentiles[i], col=i+1, lwd=2)
legend("top",paste("q90/med =",c(1,percentiles)), horiz=TRUE,cex=0.7, col=1:5, lwd=2)

mean(sub.6w.6112$'q90/med')
q90.ecdf<-ecdf(sub.6w.6112$'q90/med')
q90.ecdf(3) # gives the probability of a quantile of q90/med=3: 0.65
q90.ecdf(1) # gives the probability of a quantile of q90/med=1: 0.184
cp2$matRRfit[,'lag0']
cp2$matRRfit['0.2',]

cbind(cp2$matRRfit['0.2',],cp2$matRRlow['0.2',],cp2$matRRhigh['0.2',])*100
100-cbind(cp$matRRfit['10',],cp$matRRlow['10',],cp$matRRhigh['10',])*100
100-cbind(cp$matRRfit['32',],cp$matRRlow['32',],cp$matRRhigh['32',])*100
tail(cbind(cp$matRRfit[,'lag0'],cp$matRRlow[,'lag0'],cp$matRRhigh[,'lag0'])*100)
cbind(cp$matRRfit[,'lag0'],cp$matRRlow[,'lag0'],cp$matRRhigh[,'lag0'])*100
cp$allRRfit['10'] # 0.115
cbind(cp$allRRlow,cp$allRRhigh)['10',]
##################################################
# Abundance:
# Assessment of hydrological indices, the corresponding cross-bases, and models' results is similar to what was done with richness as above.
# only with the models fitted as:

# model.lagflow <- array(lapply(cb, function(x){mgcv::gam(obs.abundances ~ x + s(ec,k=6) + s(pH,k=6) + s(wtemp,k=6) + s(turb,k=6)+ s(vel,k=6), data=sub.6w.6112, family=tw(link="log"), na.action=na.exclude)}), c(10,3))

nrow(AICbased.abun[AICbased.abun$AIC<=2830&AICbased.abun$BIC<2880,]) # 33

#cb <- dlnm::crossbasis(flow.measures$`q80/mean`, lag=65, argvar=list(fun='lin'), arglag=list(fun="ns",knots=1),group=flow.measures$site) # good, only ec sig., 808 residual time pattern
#cb <- dlnm::crossbasis(flow.measures$`q80/mean`, lag=65, argvar=list(fun='lin'), arglag=list(fun="ns",knots=2),group=flow.measures$site) # good, only ec sig., 808 residual time pattern
#cb <- dlnm::crossbasis(flow.measures$`q80/mean`, lag=65, argvar=list(fun='lin'), arglag=list(fun="ns",knots=3),group=flow.measures$site) # good, only ec sig., 808 residual time pattern
#cb <- dlnm::crossbasis(flow.measures$`q90norm`, lag=65, argvar=list(fun='lin'), arglag=list(fun="poly",degree=3),group=flow.measures$site) #
#cb <- dlnm::crossbasis(flow.measures$`q80norm`, lag=65, argvar=list(fun='lin'), arglag=list(fun="poly",degree=3),group=flow.measures$site) # good, only ec sig., 808 residual time pattern
#cb <- dlnm::crossbasis(flow.measures$`max/med`, lag=65, argvar=list(fun='lin'), arglag=list(fun="poly",degree=3),group=flow.measures$site) # good, only ec sig., 808 residual time pattern
#cb <- dlnm::crossbasis(flow.measures$`q90/mean`, lag=65, argvar=list(fun='lin'), arglag=list(fun="ns",knots=1),group=flow.measures$site) # good, only ec sig., 808 residual time pattern
#cb <- dlnm::crossbasis(flow.measures$`meani/mean`, lag=65, argvar=list(fun='lin'), arglag=list(fun="ns",knots=1),group=flow.measures$site) # good, only ec sig., 808 residual time pattern
#cb <- dlnm::crossbasis(flow.measures$`q90/med`, lag=65, argvar=list(fun='lin'), arglag=list(fun="poly",degree=3),group=flow.measures$site) # good, only ec sig., 808 residual time pattern

#cb <- dlnm::crossbasis(flow.measures$`q80/mean`, lag=65, argvar=list(fun='lin'), arglag=list(fun="poly",degree=3),group=flow.measures$site) # good, only ec sig., 808 residual time pattern
#cb <- dlnm::crossbasis(flow.measures$`max/med`, lag=65, argvar=list(fun='lin'), arglag=list(fun="poly",degree=3),group=flow.measures$site) # good, only ec sig., 808 residual time pattern
#cb <- dlnm::crossbasis(flow.measures$`q90/mean`, lag=65, argvar=list(fun='lin'), arglag=list(fun="poly",degree=3),group=flow.measures$site) # good, only ec sig., 808 residual time pattern
#cb <- dlnm::crossbasis(flow.measures$`meani/mean`, lag=65, argvar=list(fun='lin'), arglag=list(fun="poly",degree=3),group=flow.measures$site) # good, only ec sig., 808 residual time pattern

cb <- dlnm::crossbasis(flow.measures$`q90/med`, lag=65, argvar=list(fun='lin'), arglag=list(fun="poly",degree=3),group=flow.measures$site) # good, only ec sig., 808 residual time pattern


model.lagflow <- mgcv::gam(obs.abundances ~ cb + s(ec,k=6) + s(pH,k=6) + s(wtemp,k=6)+s(turb,k=6) + s(vel,k=6), data=sub.6w.6112, family=tw(link="log"), na.action=na.exclude)
summary(model.lagflow)$residual.df # 135.28
anova(model.lagflow)
concurvity(model.lagflow, full=F)
gam.check(model.lagflow)
plot(model.lagflow,pages=1)

xyplot(residuals(model.lagflow,type="response") ~ n,groups=dist,data=sub.26w.6112,type="b",pch=19,col=c("black","grey","blue","green","red"))
xyplot(residuals(model.lagflow,type="response") ~ n|dist,data=sub.26w.6112,type="b",pch=19,col=c("black","grey","blue","green","red","cyan"))
summary(gam(residuals(model.lagflow,type="response") ~ ti(dist) + ti(n) +ti(dist,n), data=sub.6w.6112))
summary(gam(residuals(model.lagflow,type="response") ~ s(n), data=sub.6w.6112))
AIC(model.lagflow)
BIC(model.lagflow)
cp <- dlnm::crosspred(cb, model.lagflow, from=1, cen=2, lag=c(0,65), by=0.1, cumul=TRUE)
#cp <- crosspred(cb, model.lagflow, cen=1, from=0, to=30, lag=c(0,65), by=0.1, cumul=TRUE)
plot(cp,"3d", zlab="Relative effect", col="green", xlab="max/med", main="Overall effect of flow on abundance \n Reference at  q90/med=2", expand=0.6,lwd=0.5)
plot(cp, "contour", key.title=title("RE"), xlab="q90/med", ylab="Lag")

### For visual illutration (graphical abstract)
cb2 <- dlnm::crossbasis(flow.measures$`q90/med`, lag=65, argvar=list(fun='lin'), arglag=list(fun="poly",degree=3),group=flow.measures$site) # good, only ec sig., 808 residual time pattern
model.lagflow2 <- mgcv::gam(obs.abundances ~ cb2 + s(ec,k=6) + s(pH,k=6) + s(wtemp,k=6)+s(turb,k=6) + s(vel,k=6), data=sub.6w.6112, family=tw(link="log"), na.action=na.exclude)
cp2 <- dlnm::crosspred(cb2, model.lagflow2, cen=1, lag=c(0,65), by=0.1, cumul=TRUE)

min(flow.measures$'q90/med') # 0.19


### Create a tiff file for publication:
tiff(filename='delayed effect on abundance.tiff', width=130, height=100, units = 'mm', res=800,compression="lzw")
plot(cp2, "contour", key.title=title("RE"), xlab="Hydrologic index (q90/med)", ylab="", main="Relative effect (RE) of flow on \n aquatic macroinvertebrate total abundance, \n referenced against a q90/med of 2 (RE = 1)", cex.lab=0.9, cex.main=0.9)
dev.off()

tiff(filename='abundance.tiff', width=140, height=100, units = 'mm', res=800,compression="lzw")
plot(cp2, "contour", key.title=title("RE"), xlab="Hydrologic index (q90/med)", ylab="Lag (x 0.5 year)", main="", cex.lab=0.9, cex.main=0.9)
dev.off()

tiff(filename='delayed effect on abundance 2 check.tiff', width=260, height=100, units = 'mm', res=800,compression="lzw")
tiff(filename='delayed effect on abundance 3 check.tiff', width=190, height=100, units = 'mm', res=800,compression="lzw")

par(mfrow=c(2,4),cex=0.65,cex.axis=0.8,las=1,tcl=-0.5)

plot(cp2, "slices", var=0.2, col=1, lwd=2, xlab="Lag", ylab="Relative effect")
title(main="(a) q90/med = 0.2, ref. = 1", adj=0,line=1, font.main=1, cex.main=1)

plot(cp2, "slices", var=10, col=1, lwd=2, xlab="Lag", ylab="Relative effect")
title(main="(b) q90/med = 10", adj=0,line=1, font.main=1, cex.main=1)

plot(cp2, "slices", var=23, col=1, lwd=2, xlab="Lag", ylab="Relative effect")
title(main="(c) q90/med = 23", adj=0,line=1, font.main=1, cex.main=1)

plot(cp2, "slices", var=32, col=1, lwd=2, xlab="Lag", ylab="Relative effect")
title(main="(d) q90/med = 32", adj=0,line=1, font.main=1, cex.main=1.2)

plot(cp2, "slices", lag=0, col=1, lwd=2, xlab="q90/med", ylab="Relative effect")
title(main="(e) Lag = 0", adj=0,line=1, font.main=1, cex.main=1)

plot(cp2, "slices", lag=20, col=1, lwd=2, xlab="q90/med", ylab="Relative effect")
title(main="(f) Lag = 20", adj=0,line=1, font.main=1, cex.main=1)

plot(cp2, "slices", lag=30, col=1, lwd=2, xlab="q90/med", ylab="Relative effect")
title(main="(g) Lag = 30", adj=0,line=1, font.main=1, cex.main=1)

plot(cp2, "slices", lag=65, col=1, lwd=2, xlab="q90/med", ylab="Relative effect")
title(main="(h) Lag = 65", adj=0,line=1, font.main=1, cex.main=1)

dev.off()


plot(cp, "overall", ylim=c(0,2),col=4, lwd=2, ylab="Relative effect")

cp$matRRfit[,'lag0']
cbind(cp$matRRfit['3',],cp$matRRlow['3',],cp$matRRhigh['3',])*100
cbind(cp$matRRfit['23',],cp$matRRlow['23',],cp$matRRhigh['23',])*100
cbind(cp$matRRfit['10',],cp$matRRlow['10',],cp$matRRhigh['10',])*100
cbind(cp$matRRfit['32',],cp$matRRlow['32',],cp$matRRhigh['32',])*100
100-cbind(cp$matRRfit[,'lag30'],cp$matRRlow[,'lag30'],cp$matRRhigh[,'lag30'])*100
100-cbind(cp$matRRfit[,'lag20'],cp$matRRlow[,'lag20'],cp$matRRhigh[,'lag20'])*100
cp$allRRfit['10'] # 0.115
cbind(cp$allRRlow,cp$allRRhigh)['10',]

cp <- crosspred(cb, model.lagflow, at=c(1,percentiles), from=1, cen=3, lag=c(0,65), by=0.2, cumul=TRUE)
plot(cp, "slices", var=1, col=1, ylim=c(0.4,1.7), lwd=2, ylab="Relative effect", main="Lag response curves of abundance at different levels of flows, \n reference. at 3")
for(i in 1:4) lines(cp, "slices", var=percentiles[i], col=i+1, lwd=2)
legend("top",paste("q90/med =",c(1,percentiles)), horiz=TRUE,cex=0.7, col=1:5, lwd=2)

hist(flow.measures$'q90/med')


d<-data.frame(cb,sub.6w.6112[,c("ec","pH","wtemp","turb", "vel","obs.abundances")])
names(d)<-c(colnames(cb),"ec","pH","wtemp","turb","vel","abundance")
model2 <- gam(abundance ~ v1.l1 + v1.l2 + v1.l3 + s(ec, k=6) + s(pH, k=6) + s(wtemp, k=6) + s(turb, k=6) + s(vel, k=6), data=d, family=tw(link="log"), na.action=na.exclude,select=T)
summary(model2)

######## Counterfactual prediction #######
sub.6w.new <- sub.6w.6112
sub.26w.new <- sub.26w.6112

###### Abundance ####
sub.6w.new$ec <- mean(sub.6w.new$ec,na.rm=T)
sub.6w.new$pH <- mean(sub.6w.new$pH,na.rm=T)
sub.6w.new$turb <- mean(sub.6w.new$turb,na.rm=T)
sub.6w.new$wtemp <- mean(sub.6w.new$wtemp, na.rm=T)
sub.6w.new$vel <- mean(sub.6w.new$vel, na.rm=T)

cb <- dlnm::crossbasis(flow.measures$`q90/med`, lag=65, argvar=list(fun='lin'), arglag=list(fun="poly",degree=3),group=flow.measures$site) # good, only ec sig., 808 residual time pattern

d<-data.frame(cb,sub.6w.6112[,c("ec","pH","wtemp","turb", "vel","obs.abundances")])
names(d)<-c(colnames(cb),"ec","pH","wtemp","turb","vel","abundance")
model2 <- gam(abundance ~ v1.l1 + v1.l2 + v1.l3 + v1.l4 + s(ec, k=6)+ s(pH, k=6) + s(wtemp, k=6) + s(turb, k=6) + s(vel, k=6), data=d, family=tw(link="log"), na.action=na.exclude)
summary(model2)

nd <- data.frame(cb,sub.6w.new[,c("ec","pH","wtemp","turb", "vel","obs.abundances")])
names(nd)<-c(colnames(cb),"ec","pH","wtemp","turb","vel","abundance")

# Predict on the scale of the link function
pred<-predict(model2,newdata=nd,type="link")
plot(pred)
length(pred2)
# Predict on the scale of the response
pred2<-predict(model2,newdata=nd,type="response")
plot(pred2)
sub.6w.new$pred.link <- pred
sub.6w.new$pred.resp <- pred2
subset.sub.6w.new <- subset(sub.6w.new,as.numeric(format(date,"%Y"))>=1993)
xyplot(pred.resp ~ date|site, type='b', data=subset.sub.6w.new)

xyplot(pred.resp ~ date, groups=site, data=subset.sub.6w.new, type='b',pch=19, par.settings = simpleTheme(col=c("black","grey","blue","green","red"), lwd=1), auto.key=list(space="top", columns=5, title="Site", cex.title=1, lines=T, points=F), col=c("black","grey","blue","green","red"), xlab="Year", ylab="Abundance",
       panel=function(...) {
         panel.xyplot(...)
         grid.text(x=0.05,y=0.9,label="(b)",gp=gpar(cex=1.1))
       })

p.pred.abun <- xyplot(pred.resp/1000 ~ date, groups=site, data=subset.sub.6w.new, type='b',pch=19,cex=0.5,lwd=1, par.settings = simpleTheme(col=c("black","grey","blue","green","red"), lwd=1), xlab="Year", ylab=expression(paste("Total abundance (",10^3,")")),
                      panel=function(...) {
                        panel.xyplot(...)
                        grid.text(x=0.05,y=0.9,label="(b)",gp=gpar(cex=1.1))
                      })

xyplot(obs.abundances ~ date, groups=site, data=subset.sub.6w.new, type='b',pch=19, par.settings = simpleTheme(col=c("black","grey","blue","green","red","cyan"), lwd=1), auto.key=list(space="top", columns=5, title="Site", cex.title=0.6, lines=T, points=F), col=c("black","grey","blue","green","red"), xlab="Year", ylab="Abundance")

###### Richness ####
sub.26w.new$ec <- mean(sub.26w.new$ec,na.rm=T)
sub.26w.new$pH <- mean(sub.26w.new$pH,na.rm=T)
sub.26w.new$turb <- mean(sub.26w.new$turb,na.rm=T)
sub.26w.new$wtemp <- mean(sub.26w.new$wtemp, na.rm=T)
sub.26w.new$vel <- mean(sub.26w.new$vel, na.rm=T)

cb <- dlnm::crossbasis(flow.measures$`q90/med`, lag=65, argvar=list(fun='ns', knots=1), arglag=list(fun="ns", knots=1),group=flow.measures$site) # good, flow>23.

d<-data.frame(cb,sub.26w.6112[,c("ec","pH","wtemp","turb", "vel","obs.richness")])
names(d)<-c(colnames(cb),"ec","pH","wtemp","turb","vel","richness")
model3 <- gam(richness ~ v1.l1 + v1.l2 + v1.l3 + v2.l1 + v2.l2 + v2.l3  + s(ec, k=6) + s(pH, k=6) + s(wtemp, k=6) + s(turb, k=6) + s(vel, k=6), data=d, family=tw(link="log"), na.action=na.exclude)
summary(model3)

nd <- data.frame(cb,sub.26w.new[,c("ec","pH","wtemp","turb", "vel","obs.richness")])
names(nd)<-c(colnames(cb),"ec","pH","wtemp","turb","vel","richness")

# Predict on the scale of the link function
pred<-predict(model3,newdata=nd,type="link")
plot(pred)

# Predict on the scale of the response
pred2<-predict(model3,newdata=nd,type="response")
plot(pred2)
sub.26w.new$pred.link <- pred
sub.26w.new$pred.resp <- pred2
subset.sub.26w.new <- subset(sub.26w.new,as.numeric(format(date,"%Y"))>=1993)

xyplot(pred.resp ~ date|site, type='b', data=subset.sub.26w.new)
par(mfrow=c(1,1))
p.predict.richness <- xyplot(pred.resp ~ date, groups=site, data=subset.sub.26w.new, type='b', pch=19,cex=0.5,lwd=1, par.settings = simpleTheme(col=c("black","grey","blue","green","red"), cex=1, lwd=2), auto.key=list(space='top', columns=5, cex=0.8, title="Site", cex.title=1, lines=TRUE, points=FALSE, size=2.5), col=c("black","grey","blue","green","red"), xlab="", ylab="Taxa richness",
                             panel=function(...) {
                               panel.xyplot(...)
                               grid.text(x=0.05,y=0.9,label="(a)",gp=gpar(cex=1.1))
                             })
p.richness <- xyplot(richness ~ date, groups=site, data=sub.26w.new, type=c('smooth','g'), par.settings = simpleTheme(col=c("black","grey","blue","green","red","cyan"),cex=0.5, lwd=2), auto.key=list(space="top", columns=5, title="Site", cex.title=1, lines=T, points=F), col=c("black","grey","blue","green","red","cyan"))

library(latticeExtra)
p.richness + as.layer(p.predict.richness)

##### Figures for publications:
# 
#tiff(filename='Isolated effect of flows.tiff', width=260, height=100, units = 'mm', res=800,compression="lzw")

#par(mfrow=c(2,1),cex=0.65,cex.axis=0.8,las=1,tcl=-0.5) # par() doesn't work with lattice plots and complex plots
#p.predict.richness
#p.pred.abun

#dev.off()

# Try multipanelfigure package:
# Figure of isolated effects of flow:
library(multipanelfigure)
fig6 <- multi_panel_figure(width=140, height=c(75,65), columns=1, row_spacing = 0, panel_label_type ='none')
fig6 <- fill_panel(fig6, p.predict.richness)
fig6 %<>% fill_panel(p.pred.abun)
fig6 %>% save_multi_panel_figure(filename='Fig6.tiff')


# Plot observed abundance and richness:
xyplot(obs.abundances^0.25~date2, data=bug.abunrich[bug.abunrich$site!=812,], groups=as.numeric(as.character(site)),type="smooth",lwd=2, par.settings = simpleTheme(col=c("black","grey","blue","green","red"), lwd=1), auto.key=list(space="top", columns=5, title="Site", cex.title=1, lines=TRUE, points=FALSE), xlab="Time" , ylab=expression(paste("Abundance (",10^3,")")))
xyplot(obs.abundances^0.25~date2, data=bug.abunrich[bug.abunrich$site!=812,], groups=as.numeric(as.character(site)),type="smooth",lwd=2, par.settings = simpleTheme(col=c("black","grey","blue","green","red"), lwd=1), auto.key=list(space="top", columns=5, title="Site", cex.title=1, lines=TRUE, points=FALSE), xlab="Time" , ylab=expression(paste("Abundance (",10^3,")")))

sub.6w.6112.2 <- sub.6w.6112
n2 <- c(rep(NA,38), 1:66)
sub.6w.6112.2$time <- rep(n2,5)
sub.6w.6112.2 <- sub.6w.6112.2[complete.cases(sub.6w.6112.2),]

abund.gam1<-gam(obs.abundances^0.25~ti(dist,k=5,bs="cr")+ti(time,k=6,bs="cr")+ti(dist,time,k=5,bs="cr"),data=sub.6w.6112.2,family=gaussian(link=identity),na.action=na.omit)
summary(abund.gam1)
gam.check(abund.gam1)
plot(abund.gam1,pers=TRUE)
vis.gam(abund.gam1,type="response",plot.type="contour")
sub.6w.6112.2$pred.abun <- predict(abund.gam1,type="response",newdata=sub.6w.6112.2)^4



sub.26w.6112.2 <- sub.26w.6112
sub.26w.6112.2$time <- rep(n2,5)
sub.26w.6112.2 <- sub.26w.6112.2[complete.cases(sub.26w.6112.2),]

rich.gam1<-gam(I(obs.richness)~ti(dist,k=5,bs="cr")+ti(time,k=6,bs="cr")+ti(dist,time,k=5,bs="cr"),data=sub.26w.6112.2,family=gaussian(link=identity),na.action=na.omit)
summary(abund.gam2)
gam.check(abund.gam2)
plot(abund.gam2,pers=TRUE)
vis.gam(abund.gam2,type="response",plot.type="contour")
sub.26w.6112.2$pred.rich <- predict(rich.gam1,type="response",newdata=sub.26w.6112.2)

### Space-time plot for observed abundance and richness with fitted gam lines:

tiff(file="abundrichgam.tif",width=140,height=140,units="mm",pointsize = 12,bg = "transparent",res=1000,compression="lzw")

par(mar=c(1,6,1,1)+0.1,oma=c(1,1,0,1),tcl=-0.5,lwd=1)
layout(matrix(c(1,2,3),3,1,byrow=TRUE),heights=c(0.3,1,1,1))

text.size=1.5
axis.size=1
symbol.size=0.8

plot(sub.26w.6112.2$date,sub.26w.6112.2$obs.richness,type="n",bty="n",xaxt="n",yaxt="n",ylab="",xlab="")
legend("top",inset=c(0,0),legend=levels(as.factor(sub.6w.6112.2$site)),lty=1,col=c("black","grey","blue","green","red","cyan"),
       ncol=6,horiz=FALSE,cex=1.2,title="Site",bty="n")

#richness
plot(sub.26w.6112.2[sub.26w.6112.2$site==801,]$date,sub.26w.6112.2[sub.26w.6112.2$site==801,]$obs.richness,type="p",pch=19,col="black",xlab="",ylab="",ylim=c(min(sub.26w.6112.2$obs.richness,na.rm=TRUE),max(sub.26w.6112.2$obs.richness,na.rm=TRUE)),las=1,cex=symbol.size,cex.lab=text.size,cex.axis=axis.size)
title(ylab=list("Taxa richness",cex=text.size), line=4.5)
points(sub.26w.6112.2[sub.26w.6112.2$site==804,]$date,sub.26w.6112.2[sub.26w.6112.2$site==804,]$obs.richness,type="p",pch=19,col="grey",cex=symbol.size)
points(sub.26w.6112.2[sub.26w.6112.2$site==808,]$date,sub.26w.6112.2[sub.26w.6112.2$site==808,]$obs.richness,type="p",pch=19,col="blue",cex=symbol.size)
points(sub.26w.6112.2[sub.26w.6112.2$site==811,]$date,sub.26w.6112.2[sub.26w.6112.2$site==811,]$obs.richness,type="p",pch=19,col="green",cex=symbol.size)
points(sub.26w.6112.2[sub.26w.6112.2$site==814,]$date,sub.26w.6112.2[sub.26w.6112.2$site==814,]$obs.richness,type="p",pch=19,col="red",cex=symbol.size)

lines(sub.26w.6112.2[sub.26w.6112.2$site==801,]$date,sub.26w.6112.2[sub.26w.6112.2$site==801,]$pred.rich,type="l",lty=1,col="black")
lines(sub.26w.6112.2[sub.26w.6112.2$site==804,]$date,sub.26w.6112.2[sub.26w.6112.2$site==804,]$pred.rich,type="l",lty=1,col="grey")
lines(sub.26w.6112.2[sub.26w.6112.2$site==808,]$date,sub.26w.6112.2[sub.26w.6112.2$site==808,]$pred.rich,type="l",lty=1,col="blue")
lines(sub.26w.6112.2[sub.26w.6112.2$site==811,]$date,sub.26w.6112.2[sub.26w.6112.2$site==811,]$pred.rich,type="l",lty=1,col="green")
lines(sub.26w.6112.2[sub.26w.6112.2$site==814,]$date,sub.26w.6112.2[sub.26w.6112.2$site==814,]$pred.rich,type="l",lty=1,col="red")
mtext("(a)",3,-2,adj=0.05)

#abundance
plot(sub.6w.6112.2[sub.6w.6112.2$site==801,]$date,sub.6w.6112.2[sub.6w.6112.2$site==801,]$obs.abundances/1000,type="p",pch=19,col="black",xlab="Year",ylab="",ylim=c(min(sub.6w.6112.2$obs.abundances/1000,na.rm=TRUE),max(sub.6w.6112.2$obs.abundances/1000,na.rm=TRUE)),las=1,cex=symbol.size,cex.lab=text.size,cex.axis=axis.size)
title(ylab=list(expression(paste("Total abundance (",10^3,")")),cex=text.size), line=4.5)
points(sub.6w.6112.2[sub.6w.6112.2$site==804,]$date,sub.6w.6112.2[sub.6w.6112.2$site==804,]$obs.abundances/1000,type="p",pch=19,col="grey",cex=symbol.size)
points(sub.6w.6112.2[sub.6w.6112.2$site==808,]$date,sub.6w.6112.2[sub.6w.6112.2$site==808,]$obs.abundances/1000,type="p",pch=19,col="blue",cex=symbol.size)
points(sub.6w.6112.2[sub.6w.6112.2$site==811,]$date,sub.6w.6112.2[sub.6w.6112.2$site==811,]$obs.abundances/1000,type="p",pch=19,col="green",cex=symbol.size)
points(sub.6w.6112.2[sub.6w.6112.2$site==814,]$date,sub.6w.6112.2[sub.6w.6112.2$site==814,]$obs.abundances/1000,type="p",pch=19,col="red",cex=symbol.size)

lines(sub.6w.6112.2[sub.6w.6112.2$site==801,]$date,sub.6w.6112.2[sub.6w.6112.2$site==801,]$pred.abun/1000,type="l",lty=1,col="black")
lines(sub.6w.6112.2[sub.6w.6112.2$site==804,]$date,sub.6w.6112.2[sub.6w.6112.2$site==804,]$pred.abun/1000,type="l",lty=1,col="grey")
lines(sub.6w.6112.2[sub.6w.6112.2$site==808,]$date,sub.6w.6112.2[sub.6w.6112.2$site==808,]$pred.abun/1000,type="l",lty=1,col="blue")
lines(sub.6w.6112.2[sub.6w.6112.2$site==811,]$date,sub.6w.6112.2[sub.6w.6112.2$site==811,]$pred.abun/1000,type="l",lty=1,col="green")
lines(sub.6w.6112.2[sub.6w.6112.2$site==814,]$date,sub.6w.6112.2[sub.6w.6112.2$site==814,]$pred.abun/1000,type="l",lty=1,col="red")

mtext("(b)",3,-2,adj=0.05)

dev.off()

##### Plots for observed richness and richness using xyplot:
# Richness:
p.obs.rich <- xyplot(obs.richness ~ date, groups=site, data=sub.26w.6112.2, type='p', pch=19,cex=0.6, par.settings = simpleTheme(col=c("black","grey","blue","green","red"), cex=1, lwd=2), auto.key=list(space='top', columns=5, cex=0.8, title="Site", cex.title=1, lines=TRUE, points=FALSE, size=2.5, lwd=2), col=c("black","grey","blue","green","red"), xlab="", ylab="Taxa richness",
                     panel=function(...) {
                       panel.xyplot(...)
                       grid.text(x=0.05,y=0.9,label="(a)",gp=gpar(cex=1.1))
                     })
p.obs.rich2<- xyplot(pred.rich ~ date, groups=site, data=sub.26w.6112.2, type='l', lwd=1.5, par.settings = simpleTheme(col=c("black","grey","blue","green","red"), cex=1, lwd=1), auto.key=list(space='top', columns=5, cex=0.8, title="Site", cex.title=1, lines=TRUE, points=FALSE, lwd=2), col=c("black","grey","blue","green","red"), xlab="", ylab="Taxa richness",
                     panel=function(...) {
                       panel.xyplot(...)
                       grid.text(x=0.05,y=0.9,label="(a)",gp=gpar(cex=1.1))
                     })
p.rich <- p.obs.rich + as.layer(p.obs.rich2)

# Abundance:
p.obs.abun<- xyplot(obs.abundances/1000 ~ date, groups=site, data=sub.6w.6112.2, type='p', pch=19,cex=0.6, par.settings = simpleTheme(col=c("black","grey","blue","green","red"), cex=1, lwd=1), auto.key=F, col=c("black","grey","blue","green","red"), xlab="", ylab=expression(paste("Total abundance (",10^3,")")),
                    panel=function(...) {
                      panel.xyplot(...)
                      grid.text(x=0.05,y=0.9,label="(b)",gp=gpar(cex=1.1))
                    })
p.obs.abun2<- xyplot(pred.abun/1000 ~ date, groups=site, data=sub.6w.6112.2, type='l', lwd=1.5, par.settings = simpleTheme(col=c("black","grey","blue","green","red"), cex=1, lwd=1), auto.key=F, col=c("black","grey","blue","green","red"), xlab="Year", ylab=expression(paste("Total abundance (",10^3,")")),
                     panel=function(...) {
                       panel.xyplot(...)
                       grid.text(x=0.05,y=0.9,label="(b)",gp=gpar(cex=1.1))
                     })
p.abun <- p.obs.abun+ as.layer(p.obs.abun2)

fig6 <- multi_panel_figure(width=140, height=c(75,65), columns=1, row_spacing = 0, panel_label_type ='none')
fig6 <- fill_panel(fig6, p.rich)
fig6 %<>% fill_panel(p.abun)
fig6 %>% save_multi_panel_figure(filename='Fig7.tiff')

abun.gam2 <- gam(obs.abundances ~ s(ec,k=6) + s(pH,k=6) + s(wtemp,k=6)+s(turb,k=6) + s(vel,k=6)+ s(time,k=6), data=sub.6w.6112.2, family=tw(link="log"), na.action=na.exclude)
summary(abun.gam2)$residual.df # 201.1
gam.check(abun.gam2)

rich.gam2 <- gam(obs.richness ~ s(ec,k=6) + s(pH,k=6) + s(wtemp,k=6)+s(turb,k=6) + s(vel,k=6) + s(time, k=6), data=sub.26w.6112.2, family=tw(link="log"), na.action=na.exclude)
summary(rich.gam2)$residual.df#213.2
gam.check(rich.gam2)

at=format(seq(as.Date("01/06/1980", format = "%d/%m/%Y"), by = "6 month", length = 66),"%Y")

tiff(filename='FIG.tiff', width=140, height=70, units='mm', res=1000,compression="lzw")

par(mfrow=c(1,2),cex=0.65,cex.axis=0.8,las=1,tcl=-0.5)
plot(rich.gam2,select=6,xaxt = "n",xlab='',ylab='s(Time, 2.48)')
axis(1, at= 1:66, labels=at, tck=0.02)
title(xlab='Time',line=2.5, cex=0.6)
mtext(paste("(a)"),3,-1.5,adj=0.05,cex=0.65)

plot(abun.gam2,select=6,xaxt='n', xlab='',ylab='s(Time, 4.28)')
axis(1, at=1:66, labels=at,tck=0.02)
title(xlab='Time',line=2.5, cex=0.6)
mtext(paste("(b)"),3,-1.5,adj=0.05,cex=0.65)

dev.off()
