#######################################################
#######################################################
############# Cross-validation ########################

############ Abundance ##############

### Generate cross-basis of q90/med for all sites, and data for prediction:
cb <- dlnm::crossbasis(flow.measures$`q90/med`, lag=65, argvar=list(fun='lin'), arglag=list(fun="poly",degree=3),group=flow.measures$site) # good, only ec sig., 808 residual time pattern

d<-data.frame(cb,sub.6w.6112[,c("ec","pH","wtemp","turb", "vel","obs.abundances","site","n","date",'year')])
names(d)<-c(colnames(cb),"ec","pH","wtemp","turb","vel","obs.abundances","site","n","date",'year')

### Run trial to subset one site from the model using argument 'subset' in gam function:
#model.lagflow.trial <- mgcv::gam(obs.abundances ~ cb + s(ec,k=6) + s(pH,k=6) + s(wtemp,k=6)+s(turb,k=6) + s(vel,k=6), data=sub.6w.6112, family=tw(link="log"), subset=site!=801, na.action=na.exclude)
#summary(model.lagflow.trial)
#plot(model.lagflow.trial, pages=1)
#residuals(model.lagflow.trial, type='response')
#cp <- dlnm::crosspred(cb, model.lagflow.trial, cen=2, lag=c(0,65), by=0.1, cumul=TRUE)
#plot(cp,"3d", zlab="Relative effect", col="green", xlab="max/med", main="Overall effect of flow on abundance \n Reference at  q90/med=2", expand=0.6,lwd=0.5)
#plot(cp, "contour", key.title=title("RE"), xlab="q90/med", ylab="Lag")

### Model for abundance with Site 801 out ###
abun.801out <- mgcv::gam(obs.abundances ~ cb + s(ec,k=6) + s(pH,k=6) + s(wtemp,k=6)+s(turb,k=6) + s(vel,k=6), data=sub.6w.6112, family=tw(link="log"), subset=site!=801, na.action=na.exclude)
summary(abun.801out)
anova(abun.801out)
plot(abun.801out, pages=1)
residuals(abun.801out, type='response')
cp.801out <- dlnm::crosspred(cb, abun.801out, cen=2, lag=c(0,65), by=0.1, cumul=TRUE)
plot(cp.801out,"3d", zlab="Relative effect", col="green", xlab="q90/med", main="Overall effect of flow on abundance \n Reference at  q90/med=2", expand=0.6,lwd=0.5)
plot(cp.801out, "contour", key.title=title("RE"), xlab="q90/med", ylab="Lag",main='Delayed relative effects of flow on abundance,\n referenced against abundance at q90/med=2, with Site 801 left out', cex.main=0.9)

# Model for prediction for Site 801:
abun.801out.2 <- mgcv::gam(obs.abundances ~  v1.l1 + v1.l2 + v1.l3 + v1.l4  + s(ec,k=6) + s(pH,k=6) + s(wtemp,k=6)+s(turb,k=6) + s(vel,k=6), data=d, family=tw(link="log"), subset=site!=801, na.action=na.exclude)
summary(abun.801out.2)

# Data of Site 801:
nd.801 <- d[d$site==801,]

# Mean squared prediction error (MSPE) site 801:
# MSE 801 out:
var(residuals(abun.801out, type="response"),na.rm='true') # 20,496,183
#mspe.801 
var(nd.801$obs.abundances-predict(abun.801out.2, newdata=nd.801,type="response"), na.rm=TRUE)
## 8,677,469

nd.801$predict <- predict(abun.801out.2, newdata=nd.801,type="response")
#library(lattice)
#library(grid)
#library(gridExtra)
p1 <- xyplot(predict~date, type='p', pch=19, col=1, data=nd.801[nd.801$year>=1994,], ylim=c(0,14000), xlab='Year', ylab='Abundance',
             key=list(columns=1,text=list(lab=c("Observed","Predicted"),cex=0.9),
                      points=list(pch=c(1,19),col=1,type="p",size=4)),
             panel=function(...) {
               panel.xyplot(...)
               grid.text(x=0.1,y=0.9,label="Site 801",gp=gpar(cex=1))
             })
p2 <- xyplot(obs.abundances ~ date, type='p',pch=1, col=1, data=nd.801[nd.801$year>=1994,])
#library(latticeExtra)
p1+ as.layer(p2)

###############################################################
### Model for abundance with Site 804 out ###

abun.804out <- mgcv::gam(obs.abundances ~ cb + s(ec,k=6) + s(pH,k=6) + s(wtemp,k=6)+s(turb,k=6) + s(vel,k=6), data=sub.6w.6112, family=tw(link="log"), subset=site!=804, na.action=na.exclude)
summary(abun.804out)
anova(abun.804out)
plot(abun.804out, pages=1)
residuals(abun.804out, type='response')
cp.804out <- dlnm::crosspred(cb, abun.804out, cen=2, lag=c(0,65), by=0.1, cumul=TRUE)
plot(cp.804out,"3d", zlab="Relative effect", col="green", xlab="q90/med", main="Overall effect of flow on abundance \n Reference at  q90/med=2", expand=0.6,lwd=0.5)
plot(cp.804out, "contour", key.title=title("RE"), xlab="q90/med", ylab="Lag",main='Delayed relative effects of flow on abundance,\n referenced against abundance at q90/med=2, with Site 804 left out', cex.main=0.9)

# Model for prediction for Site 804:
abun.804out.2 <- mgcv::gam(obs.abundances ~  v1.l1 + v1.l2 + v1.l3 + v1.l4  + s(ec,k=6) + s(pH,k=6) + s(wtemp,k=6)+s(turb,k=6) + s(vel,k=6), data=d, family=tw(link="log"), subset=site!=804, na.action=na.exclude)
summary(abun.804out.2)

# Data of Site 804:
nd.804 <- d[d$site==804,]

# Mean squared prediction error (MSPE) site 804:
# MSE 804 out:
var(residuals(abun.804out, type="response"),na.rm='true') # 20,521,583
#mspe.804 
var(nd.804$obs.abundances-predict(abun.804out.2, newdata=nd.804,type="response"), na.rm=TRUE)
## 13,991,974

nd.804$predict <- predict(abun.804out.2, newdata=nd.804,type="response")
#library(lattice)
#library(grid)
#library(gridExtra)
p1 <- xyplot(predict~date, type='p', pch=19, col=1, data=nd.804[nd.804$year>=1994,], ylim=c(0,10000), xlab='Year', ylab='Abundance',
             key=list(columns=1,text=list(lab=c("Observed","Predicted"),cex=0.9),
                      points=list(pch=c(1,19),col=1,type="p",size=4)),
             panel=function(...) {
               panel.xyplot(...)
               grid.text(x=0.1,y=0.9,label="Site 804",gp=gpar(cex=1))
             })
p2 <- xyplot(obs.abundances ~ date, type='p',pch=1, col=1, data=nd.804[nd.804$year>=1994,])
#library(latticeExtra)
p1+ as.layer(p2)

###############################################################
### Model for abundance with Site 808 out ###

abun.808out <- mgcv::gam(obs.abundances ~ cb + s(ec,k=6) + s(pH,k=6) + s(wtemp,k=6)+s(turb,k=6) + s(vel,k=6), data=sub.6w.6112, family=tw(link="log"), subset=site!=808, na.action=na.exclude)
summary(abun.808out)
anova(abun.808out)
plot(abun.808out, pages=1)
residuals(abun.808out, type='response')
cp.808out <- dlnm::crosspred(cb, abun.808out, cen=2, lag=c(0,65), by=0.1, cumul=TRUE)
plot(cp.808out,"3d", zlab="Relative effect", col="green", xlab="q90/med", main="Overall effect of flow on abundance \n Reference at  q90/med=2", expand=0.6,lwd=0.5)
plot(cp.808out, "contour", key.title=title("RE"), xlab="q90/med", ylab="Lag",main='Delayed relative effects of flow on abundance,\n referenced against abundance at q90/med=2, with Site 808 left out', cex.main=0.9)

# Model for prediction for Site 808:
abun.808out.2 <- mgcv::gam(obs.abundances ~  v1.l1 + v1.l2 + v1.l3 + v1.l4  + s(ec,k=6) + s(pH,k=6) + s(wtemp,k=6)+s(turb,k=6) + s(vel,k=6), data=d, family=tw(link="log"), subset=site!=808, na.action=na.exclude)
summary(abun.808out.2)

# Data of Site 808:
nd.808 <- d[d$site==808,]

# Mean squared prediction error (MSPE) site 808:
# MSE 808 out:
var(residuals(abun.808out, type="response"),na.rm='true') # 16,880,786
#mspe.808 
var(nd.808$obs.abundances-predict(abun.808out.2, newdata=nd.808,type="response"), na.rm=TRUE)
## 28,404,591

nd.808$predict <- predict(abun.808out.2, newdata=nd.808,type="response")
#library(lattice)
#library(grid)
#library(gridExtra)
p1 <- xyplot(predict~date, type='p', pch=19, col=1, data=nd.808[nd.808$year>=1994,], ylim=c(0,15000), xlab='Year', ylab='Abundance',
             key=list(columns=1,text=list(lab=c("Observed","Predicted"),cex=0.9),
                      points=list(pch=c(1,19),col=1,type="p",size=4)),
             panel=function(...) {
               panel.xyplot(...)
               grid.text(x=0.1,y=0.9,label="Site 808",gp=gpar(cex=1))
             })
p2 <- xyplot(obs.abundances ~ date, type='p',pch=1, col=1, data=nd.808[nd.808$year>=1994,])
#library(latticeExtra)
p1+ as.layer(p2)


###############################################################
### Model for abundance with Site 811 out ###

abun.811out <- mgcv::gam(obs.abundances ~ cb + s(ec,k=6) + s(pH,k=6) + s(wtemp,k=6)+s(turb,k=6) + s(vel,k=6), data=sub.6w.6112, family=tw(link="log"), subset=site!=811, na.action=na.exclude)
summary(abun.811out)
anova(abun.811out)
plot(abun.811out, pages=1)
residuals(abun.811out, type='response')
cp.811out <- dlnm::crosspred(cb, abun.811out, cen=2, lag=c(0,65), by=0.1, cumul=TRUE)
plot(cp.811out,"3d", zlab="Relative effect", col="green", xlab="q90/med", main="Overall effect of flow on abundance \n Reference at  q90/med=2", expand=0.6,lwd=0.5)
plot(cp.811out, "contour", key.title=title("RE"), xlab="q90/med", ylab="Lag",main='Delayed relative effects of flow on abundance,\n referenced against abundance at q90/med=2, with Site 811 left out', cex.main=0.9)

# Model for prediction for Site 811:
abun.811out.2 <- mgcv::gam(obs.abundances ~  v1.l1 + v1.l2 + v1.l3 + v1.l4  + s(ec,k=6) + s(pH,k=6) + s(wtemp,k=6)+s(turb,k=6) + s(vel,k=6), data=d, family=tw(link="log"), subset=site!=811, na.action=na.exclude)
summary(abun.811out.2)

# Data of Site 811:
nd.811 <- d[d$site==811,]

# Mean squared prediction error (MSPE) site 811:
# MSE 811 out:
var(residuals(abun.811out, type="response"),na.rm='true') # 18,231,462
#mspe.811 
var(nd.811$obs.abundances-predict(abun.811out.2, newdata=nd.811,type="response"), na.rm=TRUE)
## 41,357,180

nd.811$predict <- predict(abun.811out.2, newdata=nd.811,type="response")
#library(lattice)
#library(grid)
#library(gridExtra)
p1 <- xyplot(predict~date, type='p', pch=19, col=1, data=nd.811[nd.811$year>=1994,], ylim=c(0,20000), xlab='Year', ylab='Abundance',
             key=list(columns=1,text=list(lab=c("Observed","Predicted"),cex=0.9),
                      points=list(pch=c(1,19),col=1,type="p",size=4)),
             panel=function(...) {
               panel.xyplot(...)
               grid.text(x=0.1,y=0.9,label="Site 811",gp=gpar(cex=1))
             })
p2 <- xyplot(obs.abundances ~ date, type='p',pch=1, col=1, data=nd.811[nd.811$year>=1994,])
#library(latticeExtra)
p1+ as.layer(p2)

###############################################################
### Model for abundance with Site 814 out ###

abun.814out <- mgcv::gam(obs.abundances ~ cb + s(ec,k=6) + s(pH,k=6) + s(wtemp,k=6)+s(turb,k=6) + s(vel,k=6), data=sub.6w.6112, family=tw(link="log"), subset=site!=814, na.action=na.exclude)
summary(abun.814out)
anova(abun.814out)
plot(abun.814out, pages=1)
residuals(abun.814out, type='response')
cp.814out <- dlnm::crosspred(cb, abun.814out, cen=2, lag=c(0,65), by=0.1, cumul=TRUE)
plot(cp.814out,"3d", zlab="Relative effect", col="green", xlab="q90/med", main="Overall effect of flow on abundance \n Reference at  q90/med=2", expand=0.6,lwd=0.5)
plot(cp.814out, "contour", key.title=title("RE"), xlab="q90/med", ylab="Lag",main='Delayed relative effects of flow on abundance,\n referenced against abundance at q90/med=2, with Site 814 left out', cex.main=0.9)

# Model for prediction for Site 814:
abun.814out.2 <- mgcv::gam(obs.abundances ~  v1.l1 + v1.l2 + v1.l3 + v1.l4  + s(ec,k=6) + s(pH,k=6) + s(wtemp,k=6)+s(turb,k=6) + s(vel,k=6), data=d, family=tw(link="log"), subset=site!=814, na.action=na.exclude)
summary(abun.814out.2)

# Data of Site 814:
nd.814 <- d[d$site==814,]

# Mean squared prediction error (MSPE) site 814:
# MSE 814 out:
var(residuals(abun.814out, type="response"),na.rm='true') # 13,864,921
#mspe.814 
var(nd.814$obs.abundances-predict(abun.814out.2, newdata=nd.814,type="response"), na.rm=TRUE)
## 1,572,214,908

nd.814$predict <- predict(abun.814out.2, newdata=nd.814,type="response")
#library(lattice)
#library(grid)
#library(gridExtra)
p1 <- xyplot(predict~date, type='p', pch=19, col=1, data=nd.814[nd.814$year>=1994,], xlab='Year', ylab='Abundance',
             key=list(columns=1,text=list(lab=c("Observed","Predicted"),cex=0.9),
                      points=list(pch=c(1,19),col=1,type="p",size=4)),
             panel=function(...) {
               panel.xyplot(...)
               grid.text(x=0.1,y=0.9,label="Site 814",gp=gpar(cex=1))
             })
p2 <- xyplot(obs.abundances ~ date, type='p',pch=1, col=1, data=nd.814[nd.814$year>=1994,])
#library(latticeExtra)
p1+ as.layer(p2)

######################################################################################
################# Cross-validation for Richness models with one site left out #########
cb2 <- dlnm::crossbasis(flow.measures$`q90/med`, lag=65, argvar=list(fun='ns', knots=1), arglag=list(fun="ns", knots=1),group=flow.measures$site) # good, flow>23.

d2<-data.frame(cb2,sub.26w.6112[,c("ec","pH","wtemp","turb", "vel","obs.richness","site","n","date",'year')])
names(d2)<-c(colnames(cb2),"ec","pH","wtemp","turb","vel","obs.richness","site","n","date",'year')

#################################################
### Model for richness with Site 801 out ###
rich.801out <- mgcv::gam(obs.richness ~ cb2 + s(ec,k=6) + s(pH,k=6) + s(wtemp,k=6)+s(turb,k=6) + s(vel,k=6), data=sub.26w.6112, family=tw(link="log"), subset=site!=801, na.action=na.exclude)
summary(rich.801out)
anova(rich.801out)
plot(rich.801out, pages=1)
residuals(rich.801out, type='response')
cp.801out.rich <- dlnm::crosspred(cb2, rich.801out, cen=2, lag=c(0,65), by=0.1, cumul=TRUE)
plot(cp.801out.rich,"3d", zlab="Relative effect", col="green", xlab="q90/med", main="Overall effect of flow on abundance \n Reference at  q90/med=2", expand=0.6,lwd=0.5)
plot(cp.801out.rich, "contour", key.title=title("RE"), xlab="q90/med", ylab="Lag",main='Delayed relative effects of flow on richness,\n referenced against richness at q90/med=2, with Site 801 left out', cex.main=0.9)

# Model for prediction for Site 801:
rich.801out.2 <- mgcv::gam(obs.richness ~  v1.l1 + v1.l2 + v1.l3 + v2.l1 + v2.l2 + v2.l3  + s(ec,k=6) + s(pH,k=6) + s(wtemp,k=6)+s(turb,k=6) + s(vel,k=6), data=d2, family=tw(link="log"), subset=site!=801, na.action=na.exclude)
summary(rich.801out.2)

# Data of Site 801:
nd.801.rich <- d2[d2$site==801,]

# Mean squared prediction error (MSPE) site 801:
# MSE 801 out:
var(residuals(rich.801out, type="response"),na.rm='true') # 42.3
#mspe.801 
var(nd.801.rich$obs.richness-predict(rich.801out.2, newdata=nd.801.rich,type="response"), na.rm=TRUE)
## 126.6

nd.801.rich$predict <- predict(rich.801out.2, newdata=nd.801.rich,type="response")
#library(lattice)
#library(grid)
#library(gridExtra)
p1 <- xyplot(predict~date, type='p', pch=19, col=1, data=nd.801.rich[nd.801.rich$year>=1994,],ylim=c(15,70), xlab='Year', ylab='Richness',
             key=list(columns=1,text=list(lab=c("Observed","Predicted"),cex=0.9),
                      points=list(pch=c(1,19),col=1,type="p",size=4)),
             panel=function(...) {
               panel.xyplot(...)
               grid.text(x=0.1,y=0.9,label="Site 801",gp=gpar(cex=1))
             })
p2 <- xyplot(obs.richness ~ date, type='p',pch=1, col=1, data=nd.801.rich[nd.801.rich$year>=1994,])
#library(latticeExtra)
p1+ as.layer(p2)

#################################################
### Model for richness with Site 804 out ###
rich.804out <- mgcv::gam(obs.richness ~ cb2 + s(ec,k=6) + s(pH,k=6) + s(wtemp,k=6)+s(turb,k=6) + s(vel,k=6), data=sub.26w.6112, family=tw(link="log"), subset=site!=804, na.action=na.exclude)
summary(rich.804out)
anova(rich.804out)
plot(rich.804out, pages=1)
residuals(rich.804out, type='response')
cp.804out.rich <- dlnm::crosspred(cb2, rich.804out, cen=2, lag=c(0,65), by=0.1, cumul=TRUE)
plot(cp.804out.rich,"3d", zlab="Relative effect", col="green", xlab="q90/med", main="Overall effect of flow on abundance \n Reference at  q90/med=2", expand=0.6,lwd=0.5)
plot(cp.804out.rich, "contour", key.title=title("RE"), xlab="q90/med", ylab="Lag",main='Delayed relative effects of flow on richness,\n referenced against richness at q90/med=2, with Site 804 left out', cex.main=0.9)

# Model for prediction for Site 804:
rich.804out.2 <- mgcv::gam(obs.richness ~  v1.l1 + v1.l2 + v1.l3 + v2.l1 + v2.l2 + v2.l3  + s(ec,k=6) + s(pH,k=6) + s(wtemp,k=6)+s(turb,k=6) + s(vel,k=6), data=d2, family=tw(link="log"), subset=site!=804, na.action=na.exclude)
summary(rich.804out.2)

# Data of Site 804:
nd.804.rich <- d2[d2$site==804,]

# Mean squared prediction error (MSPE) site 804:
# MSE 804 out:
var(residuals(rich.804out, type="response"),na.rm='true') # 45.1
#mspe.804 
var(nd.804.rich$obs.richness-predict(rich.804out.2, newdata=nd.804.rich,type="response"), na.rm=TRUE)
## 72.5

nd.804.rich$predict <- predict(rich.804out.2, newdata=nd.804.rich,type="response")
#library(lattice)
#library(grid)
#library(gridExtra)
p1 <- xyplot(predict~date, type='p', pch=19, col=1, data=nd.804.rich[nd.804.rich$year>=1994,],ylim=c(10,60), xlab='Year', ylab='Richness',
             key=list(columns=1,text=list(lab=c("Observed","Predicted"),cex=0.9),
                      points=list(pch=c(1,19),col=1,type="p",size=4)),
             panel=function(...) {
               panel.xyplot(...)
               grid.text(x=0.1,y=0.9,label="Site 804",gp=gpar(cex=1))
             })
p2 <- xyplot(obs.richness ~ date, type='p',pch=1, col=1,ylim=c(10,60), data=nd.804.rich[nd.804.rich$year>=1994,])
#library(latticeExtra)
p1+ as.layer(p2)

#################################################
### Model for richness with Site 808 out ###
rich.808out <- mgcv::gam(obs.richness ~ cb2 + s(ec,k=6) + s(pH,k=6) + s(wtemp,k=6)+s(turb,k=6) + s(vel,k=6), data=sub.26w.6112, family=tw(link="log"), subset=site!=808, na.action=na.exclude)
summary(rich.808out)
anova(rich.808out)
plot(rich.808out, pages=1)
residuals(rich.808out, type='response')
cp.808out.rich <- dlnm::crosspred(cb2, rich.808out, cen=2, lag=c(0,65), by=0.1, cumul=TRUE)
plot(cp.808out.rich,"3d", zlab="Relative effect", col="green", xlab="q90/med", main="Overall effect of flow on abundance \n Reference at  q90/med=2", expand=0.6,lwd=0.5)
plot(cp.808out.rich, "contour", key.title=title("RE"), xlab="q90/med", ylab="Lag",main='Delayed relative effects of flow on richness,\n referenced against richness at q90/med=2, with Site 808 left out', cex.main=0.9)

# Model for prediction for Site 808:
rich.808out.2 <- mgcv::gam(obs.richness ~  v1.l1 + v1.l2 + v1.l3 + v2.l1 + v2.l2 + v2.l3  + s(ec,k=6) + s(pH,k=6) + s(wtemp,k=6)+s(turb,k=6) + s(vel,k=6), data=d2, family=tw(link="log"), subset=site!=808, na.action=na.exclude)
summary(rich.808out.2)

# Data of Site 808:
nd.808.rich <- d2[d2$site==808,]

# Mean squared prediction error (MSPE) site 808:
# MSE 808 out:
var(residuals(rich.808out, type="response"),na.rm='true') # 43.8
#mspe.808 
var(nd.808.rich$obs.richness-predict(rich.808out.2, newdata=nd.808.rich,type="response"), na.rm=TRUE)
## 107.1

nd.808.rich$predict <- predict(rich.808out.2, newdata=nd.808.rich,type="response")
#library(lattice)
#library(grid)
#library(gridExtra)
p1 <- xyplot(predict~date, type='p', pch=19, col=1, data=nd.808.rich[nd.808.rich$year>=1994,],ylim=c(10,60), xlab='Year', ylab='Richness',
             key=list(columns=1,text=list(lab=c("Observed","Predicted"),cex=0.9),
                      points=list(pch=c(1,19),col=1,type="p",size=4)),
             panel=function(...) {
               panel.xyplot(...)
               grid.text(x=0.1,y=0.9,label="Site 808",gp=gpar(cex=1))
             })
p2 <- xyplot(obs.richness ~ date, type='p',pch=1, col=1,ylim=c(10,60), data=nd.808.rich[nd.808.rich$year>=1994,])
#library(latticeExtra)
p1+ as.layer(p2)

#################################################
### Model for richness with Site 811 out ###
rich.811out <- mgcv::gam(obs.richness ~ cb2 + s(ec,k=6) + s(pH,k=6) + s(wtemp,k=6)+s(turb,k=6) + s(vel,k=6), data=sub.26w.6112, family=tw(link="log"), subset=site!=811, na.action=na.exclude)
summary(rich.811out)
anova(rich.811out)
plot(rich.811out, pages=1)
residuals(rich.811out, type='response')
cp.811out.rich <- dlnm::crosspred(cb2, rich.811out, cen=2, lag=c(0,65), by=0.1, cumul=TRUE)
plot(cp.811out.rich,"3d", zlab="Relative effect", col="green", xlab="q90/med", main="Overall effect of flow on abundance \n Reference at  q90/med=2", expand=0.6,lwd=0.5)
plot(cp.811out.rich, "contour", key.title=title("RE"), xlab="q90/med", ylab="Lag",main='Delayed relative effects of flow on richness,\n referenced against richness at q90/med=2, with Site 811 left out', cex.main=0.9)

# Model for prediction for Site 811:
rich.811out.2 <- mgcv::gam(obs.richness ~  v1.l1 + v1.l2 + v1.l3 + v2.l1 + v2.l2 + v2.l3  + s(ec,k=6) + s(pH,k=6) + s(wtemp,k=6)+s(turb,k=6) + s(vel,k=6), data=d2, family=tw(link="log"), subset=site!=811, na.action=na.exclude)
summary(rich.811out.2)

# Data of Site 811:
nd.811.rich <- d2[d2$site==811,]

# Mean squared prediction error (MSPE) site 811:
# MSE 811 out:
var(residuals(rich.811out, type="response"),na.rm='true') # 49.2
#mspe.811 
var(nd.811.rich$obs.richness-predict(rich.811out.2, newdata=nd.811.rich,type="response"), na.rm=TRUE)
## 69.4

nd.811.rich$predict <- predict(rich.811out.2, newdata=nd.811.rich,type="response")
#library(lattice)
#library(grid)
#library(gridExtra)
p1 <- xyplot(predict~date, type='p', pch=19, col=1, data=nd.811.rich[nd.811.rich$year>=1994,],ylim=c(10,60), xlab='Year', ylab='Richness',
             key=list(columns=1,text=list(lab=c("Observed","Predicted"),cex=0.9),
                      points=list(pch=c(1,19),col=1,type="p",size=4)),
             panel=function(...) {
               panel.xyplot(...)
               grid.text(x=0.1,y=0.9,label="Site 811",gp=gpar(cex=1))
             })
p2 <- xyplot(obs.richness ~ date, type='p',pch=1, col=1,ylim=c(10,60), data=nd.811.rich[nd.811.rich$year>=1994,])
#library(latticeExtra)
p1+ as.layer(p2)


#################################################
### Model for richness with Site 814 out ###
rich.814out <- mgcv::gam(obs.richness ~ cb2 + s(ec,k=6) + s(pH,k=6) + s(wtemp,k=6)+s(turb,k=6) + s(vel,k=6), data=sub.26w.6112, family=tw(link="log"), subset=site!=814, na.action=na.exclude)
summary(rich.814out)
anova(rich.814out)
plot(rich.814out, pages=1)
residuals(rich.814out, type='response')
cp.814out.rich <- dlnm::crosspred(cb2, rich.814out, cen=2, lag=c(0,65), by=0.1, cumul=TRUE)
#plot(cp.814out.rich,"3d", zlab="Relative effect", col="green", xlab="q90/med", main="Overall effect of flow on abundance \n Reference at  q90/med=2", expand=0.6,lwd=0.5)
plot(cp.814out.rich, "contour", key.title=title("RE"), xlab="q90/med", ylab="Lag",main='Delayed relative effects of flow on richness,\n referenced against richness at q90/med=2, with Site 814 left out', cex.main=0.9)

# Model for prediction for Site 814:
rich.814out.2 <- mgcv::gam(obs.richness ~  v1.l1 + v1.l2 + v1.l3 + v2.l1 + v2.l2 + v2.l3  + s(ec,k=6) + s(pH,k=6) + s(wtemp,k=6)+s(turb,k=6) + s(vel,k=6), data=d2, family=tw(link="log"), subset=site!=814, na.action=na.exclude)
summary(rich.814out.2)

# Data of Site 814:
nd.814.rich <- d2[d2$site==814,]

# Mean squared prediction error (MSPE) site 814:
# MSE 814 out:
var(residuals(rich.814out, type="response"),na.rm='true') # 53.4
#mspe.814 
var(nd.814.rich$obs.richness-predict(rich.814out.2, newdata=nd.814.rich,type="response"), na.rm=TRUE)
## 65.3

nd.814.rich$predict <- predict(rich.814out.2, newdata=nd.814.rich,type="response")
#library(lattice)
#library(grid)
#library(gridExtra)
p1 <- xyplot(predict~date, type='p', pch=19, col=1, data=nd.814.rich[nd.814.rich$year>=1994,],ylim=c(10,60), xlab='Year', ylab='Richness',
             key=list(columns=1,text=list(lab=c("Observed","Predicted"),cex=0.9),
                      points=list(pch=c(1,19),col=1,type="p",size=4)),
             panel=function(...) {
               panel.xyplot(...)
               grid.text(x=0.1,y=0.9,label="Site 814",gp=gpar(cex=1))
             })
p2 <- xyplot(obs.richness ~ date, type='p',pch=1, col=1,ylim=c(10,60), data=nd.814.rich[nd.814.rich$year>=1994,])
#library(latticeExtra)
p1+ as.layer(p2)


##################################################################################
# Using the model for all sites to predict abundance/richness for each site:
## Abundance:

#cb <- dlnm::crossbasis(flow.measures$`q90/med`, lag=65, argvar=list(fun='lin'), arglag=list(fun="poly",degree=3),group=flow.measures$site) # good, only ec sig., 808 residual time pattern
#model.lagflow <- mgcv::gam(obs.abundances ~ cb + s(ec,k=6) + s(pH,k=6) + s(wtemp,k=6)+s(turb,k=6) + s(vel,k=6), data=sub.6w.6112, family=tw(link="log"), na.action=na.exclude)

### Model for prediction:
#d<-data.frame(cb,sub.6w.6112[,c("ec","pH","wtemp","turb", "vel","obs.abundances")])
#names(d)<-c(colnames(cb),"ec","pH","wtemp","turb","vel","abundance")
model2 <- gam(obs.abundances ~ v1.l1 + v1.l2 + v1.l3 +v1.l4+ s(ec, k=6) + s(pH, k=6) + s(wtemp, k=6) + s(turb, k=6) + s(vel, k=6), data=d, family=tw(link="log"), na.action=na.exclude,select=T)
summary(model2)

# MSE of the model for abundance:
var(residuals(model2, type="response"),na.rm='true') # 19,040,673

# Prediction for site 801:
 # mspe 801:
var(nd.801$obs.abundances-predict(model2, newdata=nd.801,type="response"), na.rm=TRUE)
#7,696,251
nd.801$predict.all <- predict(model2, newdata = nd.801, type='response')
p1 <- xyplot(predict.all~date, type='p', pch=19,col=1, data=nd.801[nd.801$year>=1994,], ylim=c(0,13000), ylab="Abundance",xlab="Year",
            key=list(columns=1,text=list(lab=c("Observed","Predicted"),cex=0.9),
                     points=list(pch=c(1,19),col=1,type="p",size=4)),
                     panel=function(...) {
               panel.xyplot(...)
               grid.text(x=0.1,y=0.92,label="Site 801",gp=gpar(cex=1))
             } )
p2 <- xyplot(obs.abundances ~ date, type='p', col=1, data=nd.801[nd.801$year>=1994,])
p1+ as.layer(p2)

# Prediction for site 804:
var(nd.804$obs.abundances-predict(model2, newdata=nd.804,type="response"), na.rm=TRUE)
#12,073,536
nd.804$predict.all <- predict(model2, newdata = nd.804, type='response')
p1 <- xyplot(predict.all~date, type='p', pch=19,col=1, data=nd.804[nd.804$year>=1994,], ylim=c(0,22000), ylab="Abundance",xlab="Year",
            key=list(columns=1,text=list(lab=c("Observed","Predicted"),cex=0.9),
                     points=list(pch=c(1,19),col=1,type="p",size=4)),
                     panel=function(...) {
               panel.xyplot(...)
               grid.text(x=0.1,y=0.92,label="Site 804",gp=gpar(cex=1))
             } )
p2 <- xyplot(obs.abundances ~ date, type='p', col=1, data=nd.804[nd.804$year>=1994,])
p1+ as.layer(p2)

# Prediction for site 808:
var(nd.808$obs.abundance-predict(model2, newdata=nd.808,type="response"), na.rm=TRUE)
#  25,677,071
nd.808$predict.all <- predict(model2, newdata = nd.808, type='response')
p1 <- xyplot(predict.all~date, type='p', pch=19,col=1, data=nd.808[nd.808$year>=1994,], ylim=c(0,27000), ylab="Abundance",xlab="Year",
            key=list(columns=1,text=list(lab=c("Observed","Predicted"),cex=0.9),
                     points=list(pch=c(1,19),col=1,type="p",size=4)),
                     panel=function(...) {
               panel.xyplot(...)
               grid.text(x=0.1,y=0.92,label="Site 808",gp=gpar(cex=1))
             } )
p2 <- xyplot(obs.abundances ~ date, type='p', col=1, data=nd.808[nd.808$year>=1994,])
p1+ as.layer(p2)

# Prediction for site 811:
var(nd.811$obs.abundances-predict(model2, newdata=nd.811,type="response"), na.rm=TRUE)
#21,365,943
nd.811$predict.all <- predict(model2, newdata = nd.811, type='response')
p1 <- xyplot(predict.all~date, type='p', pch=19,col=1, data=nd.811[nd.811$year>=1994,], ylim=c(0,20000), ylab="Abundance",xlab="Year",
            key=list(columns=1,text=list(lab=c("Observed","Predicted"),cex=0.9),
                     points=list(pch=c(1,19),col=1,type="p",size=4)),
                     panel=function(...) {
               panel.xyplot(...)
               grid.text(x=0.1,y=0.92,label="Site 811",gp=gpar(cex=1))
             } )
p2 <- xyplot(obs.abundances ~ date, type='p', col=1, data=nd.811[nd.811$year>=1994,])
p1+ as.layer(p2)

# Prediction for site 814:
var(nd.814$obs.abundances-predict(model2, newdata=nd.814,type="response"), na.rm=TRUE)

nd.814$predict.all <- predict(model2, newdata = nd.814, type='response')
p1 <- xyplot(predict.all~date, type='p', pch=19,col=1, data=nd.814[nd.814$year>=1994,], ylim=c(0,30000), ylab="Abundance",xlab="Year",
            key=list(columns=1,text=list(lab=c("Observed","Predicted"),cex=0.9),
                     points=list(pch=c(1,19),col=1,type="p",size=4)),
                     panel=function(...) {
               panel.xyplot(...)
               grid.text(x=0.1,y=0.92,label="Site 814",gp=gpar(cex=1))
             } )
p2 <- xyplot(obs.abundances ~ date, type='p', col=1, data=nd.814[nd.814$year>=1994,])
p1+ as.layer(p2)

########################################
#### Richness (Model for all sites)

#cb2 <- dlnm::crossbasis(flow.measures$`q90/med`, lag=65, argvar=list(fun='ns', knots=1), arglag=list(fun="ns", knots=1),group=flow.measures$site) # good, flow>23.

#d2<-data.frame(cb,sub.26w.6112[,c("ec","pH","wtemp","turb", "vel","obs.richness",'date','n','site')])
#names(d2)<-c(colnames(cb),"ec","pH","wtemp","turb","vel","richness",'date','n','site')
model3 <- gam(obs.richness ~ v1.l1 + v1.l2 + v1.l3 + v2.l1 + v2.l2 + v2.l3  + s(ec, k=6) + s(pH, k=6) + s(wtemp, k=6) + s(turb, k=6) + s(vel, k=6), data=d2, family=tw(link="log"), na.action=na.exclude)
summary(model3)
#xyplot(residuals(model3,type="response") ~ n,groups=site,data=d,type="b",pch=19,col=c("black","grey","blue","green","red","cyan"))
#xyplot(residuals(model3,type="response") ~ n|as.factor(site),data=d,type="b",pch=19, as.table=TRUE)

# MSE of the model for richness:
var(residuals(model3, type="response"),na.rm='true')

# Prediction for site 801 (richness):
 # mspe 801:
var(nd.801.rich$obs.richness-predict(model3, newdata=nd.801.rich,type="response"), na.rm=TRUE)

nd.801.rich$predict.all.rich <- predict(model3, newdata = nd.801.rich, type='response')
p1 <- xyplot(predict.all.rich~date, type='p', pch=19,col=1, data=nd.801.rich[nd.801.rich$year>=1994,], ylim=c(20,70), ylab="Richness",xlab="Year",
            key=list(columns=1,text=list(lab=c("Observed","Predicted"),cex=0.9),
                     points=list(pch=c(1,19),col=1,type="p",size=4)),
                     panel=function(...) {
               panel.xyplot(...)
               grid.text(x=0.1,y=0.92,label="Site 801",gp=gpar(cex=1))
             } )
p2 <- xyplot(obs.richness ~ date, type='p', col=1, data=nd.801.rich[nd.801.rich$year>=1994,])
p1+ as.layer(p2)

# Prediction for site 804 (richness):
 # mspe 804:
var(nd.804.rich$obs.richness-predict(model3, newdata=nd.804.rich,type="response"), na.rm=TRUE)

nd.804.rich$predict.all.rich <- predict(model3, newdata = nd.804.rich, type='response')
p1 <- xyplot(predict.all.rich~date, type='p', pch=19,col=1, data=nd.804.rich[nd.804.rich$year>=1994,], ylim=c(10,60), ylab="Richness",xlab="Year",
            key=list(columns=1,text=list(lab=c("Observed","Predicted"),cex=0.9),
                     points=list(pch=c(1,19),col=1,type="p",size=4)),
                     panel=function(...) {
               panel.xyplot(...)
               grid.text(x=0.1,y=0.92,label="Site 804",gp=gpar(cex=1))
             } )
p2 <- xyplot(obs.richness ~ date, type='p', col=1, data=nd.804.rich[nd.804.rich$year>=1994,])
p1+ as.layer(p2)

# Prediction for site 808 (richness):
 # mspe 808:
var(nd.808.rich$obs.richness-predict(model3, newdata=nd.808.rich,type="response"), na.rm=TRUE)

nd.808.rich$predict.all.rich <- predict(model3, newdata = nd.808.rich, type='response')
p1 <- xyplot(predict.all.rich~date, type='p', pch=19,col=1, data=nd.808.rich[nd.808.rich$year>=1994,], ylim=c(0,60), ylab="Richness",xlab="Year",
            key=list(columns=1,text=list(lab=c("Observed","Predicted"),cex=0.9),
                     points=list(pch=c(1,19),col=1,type="p",size=4)),
                     panel=function(...) {
               panel.xyplot(...)
               grid.text(x=0.1,y=0.92,label="Site 808",gp=gpar(cex=1))
             } )
p2 <- xyplot(obs.richness ~ date, type='p', col=1, data=nd.808.rich[nd.808.rich$year>=1994,])
p1+ as.layer(p2)

# Prediction for site 811 (richness):
 # mspe 811:
var(nd.811.rich$obs.richness-predict(model3, newdata=nd.811.rich,type="response"), na.rm=TRUE)
# 25.7
nd.811.rich$predict.all.rich <- predict(model3, newdata = nd.811.rich, type='response')
p1 <- xyplot(predict.all.rich~date, type='p', pch=19,col=1, data=nd.811.rich[nd.811.rich$year>=1994,], ylim=c(10,60), ylab="Richness",xlab="Year",
            key=list(columns=1,text=list(lab=c("Observed","Predicted"),cex=0.9),
                     points=list(pch=c(1,19),col=1,type="p",size=4)),
                     panel=function(...) {
               panel.xyplot(...)
               grid.text(x=0.1,y=0.92,label="Site 811",gp=gpar(cex=1))
             } )
p2 <- xyplot(obs.richness ~ date, type='p', col=1, data=nd.811.rich[nd.811.rich$year>=1994,])
p1+ as.layer(p2)

# Prediction for site 814 (richness):
 # mspe 814:
var(nd.814.rich$obs.richness-predict(model3, newdata=nd.814.rich,type="response"), na.rm=TRUE)
# 31.7
nd.814.rich$predict.all.rich <- predict(model3, newdata = nd.814.rich, type='response')
p1 <- xyplot(predict.all.rich~date, type='p', pch=19,col=1, data=nd.814.rich[nd.814.rich$year>=1994,], ylim=c(10,60), ylab="Richness",xlab="Year",
            key=list(columns=1,text=list(lab=c("Observed","Predicted"),cex=0.9),
                     points=list(pch=c(1,19),col=1,type="p",size=4)),
                     panel=function(...) {
               panel.xyplot(...)
               grid.text(x=0.1,y=0.92,label="Site 814",gp=gpar(cex=1))
             } )
p2 <- xyplot(obs.richness ~ date, type='p', col=1, data=nd.814.rich[nd.814.rich$year>=1994,])
p1+ as.layer(p2)

##################################################################################
##################################################################################
### 